<?xml version="1.0"?>
<!-- purpletohtml.xsl ================================================
     Author: Eugene Eric Kim <eekim@eekim.com>
     URL: http://www.eekim.com/software/purple/

     Version: 0.4
     $Id: purpletohtml.xsl,v 1.6 2001/08/28 06:43:52 eekim Exp $

     Copyright (c) Eugene Eric Kim 2000-2001.  All rights reserved.
     See COPYING for licensing terms.
================================================================== -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0">

<!-- To generate XHTML, change method to "xml" and set parameter
     "output" to "clean". -->
<xsl:output method="html" indent="yes"/>

<!-- ===== global variables ===== -->
<xsl:param name="output"/>  <!-- if "clean", generate clean HTML -->
<xsl:param name="css"/> <!-- use this file for styles instead of style tag -->
<xsl:param name="hid"/> <!-- if "off", won't print HIDs -->
<xsl:variable name="version" select="0.4"/>

<!-- ===== construct result set ===== -->
<xsl:template match="/">
  <html>
    <head>
      <title><xsl:value-of select="purple/docinfo/title"/></title>
      <meta name="generator" content="Purple v{$version}"/>
      <xsl:if test="$css">
      <link href="{$css}" rel="stylesheet" type="text/css"/>
      </xsl:if>
      <style type="text/css">
        body {
          background-color:#FFFFFF; padding-bottom: 50em;}
        h1.title {text-align: center;}
        p.docinfo {text-align: center;}
        p.footer {text-align: right;}
        <!-- additional stylesheet elements for clean HTML output.
             I could include it even in the hacked HTML output, but
             since they wouldn't be used, I figured it's better off
             left out. -->
        <xsl:if test="$output = 'clean'">
        div.indented {margin-left: 3em;}
        </xsl:if>
        div.example {
          display:block; background-color:#C0FFFF;
          margin-left:10%; margin-right:10%;
          border-width:1pt;}
        div.image {display:block; margin-left:10%; margin-right:10%;}
        p.caption {margin-left:10%; margin-right:10%;}
        <!-- purple numbers -->
        <xsl:if test="$css = false()">
        a.hid {
          font-family: "Helvetica", "Arial", sans-serif;
          font-size: x-small;
          font-style: italic;
          font-weight: bold;
          text-decoration: none;
          color: #C8A8FF;}
        a.nid {
          font-family: "Helvetica", "Arial", sans-serif;
          font-style: normal;
          font-weight: bold;
          font-size: x-small;
          text-decoration: none;
          color: #C8A8FF;}
        </xsl:if>
      </style>
    </head>
    <body>
      <h1 class="title"><xsl:value-of select="purple/docinfo/title"/></h1>

      <p class="docinfo">
      <!-- check for multiple authors.  If there are more than one,
           output each of them separated by line breaks.  The count() is
           probably unnecessary; I'm trying to avoid the extraneous break
           element at the end of the paragraph, but if there are multiple
           authors, you get the extraneous break anyway. -->
      <xsl:choose>
        <xsl:when test="count(purple/docinfo/author) = 1">
          <xsl:value-of select="purple/docinfo/author/name"/>
          <xsl:text> </xsl:text>
          <a href="mailto:{purple/docinfo/author/email}">&lt;<xsl:value-of select="purple/docinfo/author/email"/>&gt;</a>
        </xsl:when>
        <xsl:otherwise>
          <xsl:for-each select="purple/docinfo/author">
            <xsl:value-of select="name"/>
            <xsl:text> </xsl:text>
            <a href="mailto:{email}">&lt;<xsl:value-of select="email"/>&gt;</a>
            <br/>
          </xsl:for-each>
        </xsl:otherwise>
      </xsl:choose>
      </p>

      <p class="docinfo">Version
      <xsl:value-of select="purple/docinfo/version"/><br/>
      <xsl:value-of select="purple/docinfo/datepublished"/>
      </p>

      <hr />

      <xsl:apply-templates select="purple/section"/>

      <hr />

      <p class="footer"><i>Document developed using
      <a href="http://www.eekim.com/software/purple/">Purple</a></i></p>
    </body>
  </html>
</xsl:template>

<xsl:template match="section">
  <xsl:if test="h = true()">
  <h3><a id="nid{h/@nid}" name="nid{h/@nid}" />
    <xsl:if test="$hid != 'off'">
      <a id="hid{h/@hid}" name="hid{h/@hid}" />
    </xsl:if>
  <xsl:value-of select="h"/>
  &#xA0;&#xA0;
  <xsl:if test="$hid !='off'">
    <a class="hid" href="#hid{h/@hid}"><xsl:value-of select="h/@hid"/></a>&#xA0;
  </xsl:if>
  <a class="nid" href="#nid{h/@nid}">(<xsl:value-of select="h/@nid"/>)</a>
  </h3>
  </xsl:if>
  <xsl:choose>
    <xsl:when test="$output = 'clean'">
      <div class="indented">
      <xsl:apply-templates select="p | list | example | figure | section"/>
      </div>
    </xsl:when>
    <xsl:otherwise>
      <ul>
      <xsl:apply-templates select="p | list | example | figure | section"/>
      </ul>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="p">
  <p><a id="nid{@nid}" name="nid{@nid}" />
  <xsl:if test="$hid != 'off'">
    <a id="hid{@hid}" name="hid{@hid}" />
  </xsl:if>
  <xsl:apply-templates select="text() | link | i | b"/>
  &#xA0;&#xA0;
  <xsl:if test="$hid != 'off'">
    <a class="hid" href="#hid{@hid}"><xsl:value-of select="@hid"/></a>&#xA0;
  </xsl:if>
  <a class="nid" href="#nid{@nid}">(<xsl:value-of select="@nid"/>)</a>
  </p>
</xsl:template>

<xsl:template match="list">
  <ul>
    <xsl:apply-templates/>
  </ul>
</xsl:template>

<xsl:template match="item">
  <li><a id="nid{@nid}" name="nid{@nid}" />
  <xsl:if test="$hid != 'off'">
    <a id="hid{@hid}" name="hid{@hid}" />
  </xsl:if>
  <xsl:apply-templates select="text() | link | i | b"/>
  &#xA0;&#xA0;
  <xsl:if test="$hid != 'off'">
    <a class="hid" href="#hid{@hid}"><xsl:value-of select="@hid"/></a>&#xA0;
  </xsl:if>
  <a class="nid" href="#nid{@nid}">(<xsl:value-of select="@nid"/>)</a>
  </li>
</xsl:template>

<xsl:template match="example">
  <div class="example"><pre><a id="nid{@nid}" name="nid{@nid}" />
  <xsl:if test="$hid != 'off'">
    <a id="hid{@hid}" name="hid{@hid}" />
  </xsl:if>
  <a name="ex-{@num}"/>
  <xsl:value-of select="listing"/></pre></div>
  <p class="caption"><b>Example <xsl:value-of select="@num"/>.</b><xsl:text> </xsl:text>
  <xsl:value-of select="caption"/>
  &#xA0;&#xA0;
  <xsl:if test="$hid != 'off'">
    <a class="hid" href="#hid{@hid}"><xsl:value-of select="@hid"/></a>&#xA0;
  </xsl:if>
  <a class="nid" href="#nid{@nid}">(<xsl:value-of select="@nid"/>)</a>
  </p>
</xsl:template>

<xsl:template match="figure">
  <div class="image"><a id="nid{@nid}" name="nid{@nid}" />
  <xsl:if test="$hid != 'off'">
    <a id="hid{@hid}" name="hid{@hid}" />
  </xsl:if>
  <a name="fig-{@num}"/>
  <img src="{image/@src}" alt="[Figure {@num}]"/></div>
  <p class="caption"><b>Figure <xsl:value-of select="@num"/>.</b><xsl:text> </xsl:text>
  <xsl:value-of select="caption"/>
  &#xA0;&#xA0;
  <xsl:if test="$hid != 'off'">
    <a class="hid" href="#hid{@hid}"><xsl:value-of select="@hid"/></a>&#xA0;
  </xsl:if>
  <a class="nid" href="#nid{@nid}">(<xsl:value-of select="@nid"/>)</a>
  </p>
</xsl:template>

<!-- formatting elements -->

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="link">
  <a href="{@href}"><xsl:value-of select="."/></a>
</xsl:template>

<xsl:template match="i">
  <i><xsl:value-of select="."/></i>
</xsl:template>

<xsl:template match="b">
  <b><xsl:value-of select="."/></b>
</xsl:template>

</xsl:stylesheet>
